import factory


class DatatableFactory(factory.Factory):

    class Meta:
        model = dict
    id = factory.Sequence(lambda n: n)
    vendor_code = factory.Sequence(lambda n: 'VENDOR_CODE{0}'.format(n))
    datatable_code = factory.Sequence(lambda n: 'DATATABLE_CODE{0}'.format(n))
    name = factory.Sequence(lambda n: 'DATATABLE{0}'.format(n))



import re
import unittest
import httpretty
import json
import pandas
from mock import patch, call
import quandl
from quandl.utils.request_type_util import RequestType
from quandl.errors.quandl_error import InvalidRequestError
from datetime import date


class GetPointInTimeTest(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        httpretty.enable()
        httpretty.register_uri(httpretty.GET,
                               re.compile('https://www.quandl.com/api/v3/pit*'),
                               body=json.dumps({}))

    @classmethod
    def tearDownClass(cls):
        httpretty.disable()
        httpretty.reset()

    def tearDown(self):
        RequestType.USE_GET_REQUEST = True

    @patch('quandl.connection.Connection.request')
    def test_get_point_in_time_returns_data_frame_object(self, mock):
        df = quandl.get_point_in_time('ZACKS/FC', interval='asofdate', date='2020-01-01')
        self.assertIsInstance(df, pandas.core.frame.DataFrame)

    @patch('quandl.connection.Connection.request')
    def test_asofdate_call_connection(self, mock):
        quandl.get_point_in_time('ZACKS/FC', interval='asofdate', date='2020-01-01')
        expected = call('get', 'pit/ZACKS/FC/asofdate/2020-01-01', params={})
        self.assertEqual(mock.call_args, expected)

    @patch('quandl.connection.Connection.request')
    def test_asofdate_call_without_date(self, mock):
        quandl.get_point_in_time('ZACKS/FC', interval='asofdate')
        expected = call('get', "pit/ZACKS/FC/asofdate/%s" % date.today(), params={})
        self.assertEqual(mock.call_args, expected)

    @patch('quandl.connection.Connection.request')
    def test_from_call_connection(self, mock):
        quandl.get_point_in_time(
            'ZACKS/FC',
            interval='from',
            start_date='2020-01-01',
            end_date='2020-01-02'
        )
        expected = call('get', 'pit/ZACKS/FC/from/2020-01-01/to/2020-01-02', params={})
        self.assertEqual(mock.call_args, expected)

    @patch('quandl.connection.Connection.request')
    def test_between_call_connection(self, mock):
        quandl.get_point_in_time(
            'ZACKS/FC',
            interval='between',
            start_date='2020-01-01',
            end_date='2020-01-02'
        )
        expected = call('get', 'pit/ZACKS/FC/between/2020-01-01/2020-01-02', params={})
        self.assertEqual(mock.call_args, expected)

    @patch('quandl.connection.Connection.request')
    def test_invalid_interval_connection(self, mock):
        self.assertRaises(InvalidRequestError, lambda: quandl.get_point_in_time('ZACKS/FC'))
        self.assertRaises(
            InvalidRequestError,
            lambda: quandl.get_point_in_time('ZACKS/FC', interval='quandl')
        )

    @patch('quandl.connection.Connection.request')
    def test_invalid_from_connection(self, mock):
        self.assertRaises(
            InvalidRequestError,
            lambda: quandl.get_point_in_time('ZACKS/FC', interval='from')
        )
        self.assertRaises(
            InvalidRequestError,
            lambda: quandl.get_point_in_time('ZACKS/FC', interval='from', start_date='2020-01-01')
        )
        self.assertRaises(
            InvalidRequestError,
            lambda: quandl.get_point_in_time('ZACKS/FC', interval='from', end_date='2020-01-02')
        )

    @patch('quandl.connection.Connection.request')
    def test_invalid_between_connection(self, mock):
        self.assertRaises(
            InvalidRequestError,
            lambda: quandl.get_point_in_time('ZACKS/FC', interval='between')
        )
        self.assertRaises(
            InvalidRequestError,
            lambda: quandl.get_point_in_time(
                'ZACKS/FC',
                interval='between',
                start_date='2020-01-01'
            )
        )
        self.assertRaises(
            InvalidRequestError,
            lambda: quandl.get_point_in_time('ZACKS/FC', interval='between', end_date='2020-01-02')
        )



import json
import re

import httpretty
from mock import call, patch

from quandl.model.point_in_time import PointInTime
from test.test_retries import ModifyRetrySettingsTestCase
from quandl.utils.request_type_util import RequestType


class GetPointInTimeTest(ModifyRetrySettingsTestCase):

    @classmethod
    def setUpClass(cls):
        httpretty.enable()
        httpretty.register_uri(httpretty.GET,
                               re.compile('https://www.quandl.com/api/v3/pit/*'),
                               body=json.dumps({}))

    @classmethod
    def tearDownClass(cls):
        httpretty.disable()
        httpretty.reset()

    def tearDown(self):
        RequestType.USE_GET_REQUEST = True

    @patch('quandl.connection.Connection.request')
    def test_asofdate_call_connection(self, mock):
        PointInTime(
            'ZACKS/FC',
            pit={
                'interval': 'asofdate',
                'date': '2020-01-01'
            }
        ).data()
        expected = call('get', 'pit/ZACKS/FC/asofdate/2020-01-01', params={})
        self.assertEqual(mock.call_args, expected)

    @patch('quandl.connection.Connection.request')
    def test_from_call_connection(self, mock):
        PointInTime(
            'ZACKS/FC',
            pit={
                'interval': 'from',
                'start_date': '2020-01-01',
                'end_date': '2020-01-02'
            }
        ).data()
        expected = call('get', 'pit/ZACKS/FC/from/2020-01-01/to/2020-01-02', params={})
        self.assertEqual(mock.call_args, expected)

    @patch('quandl.connection.Connection.request')
    def test_between_call_connection(self, mock):
        PointInTime(
            'ZACKS/FC',
            pit={
                'interval': 'between',
                'start_date': '2020-01-01',
                'end_date': '2020-01-02'
            }
        ).data()
        expected = call('get', 'pit/ZACKS/FC/between/2020-01-01/2020-01-02', params={})
        self.assertEqual(mock.call_args, expected)
